@@ -14,18 +14,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__all__ = ['build_neck']
+__all__ = ["build_neck"]
+
 
 def build_neck(config):
     from .craft_fpn import CRAFTFPN
     from .db_fpn import DBFPN
     from .east_fpn import EASTFPN
-    from .sast_fpn import SASTFPN
     from .rnn import SequenceEncoder
-    support_dict = ['CRAFTFPN', 'DBFPN', 'EASTFPN', 'SASTFPN', 'SequenceEncoder']
+    from .sast_fpn import SASTFPN
 
-    module_name = config.pop('name')
-    assert module_name in support_dict, Exception('neck only support {}'.format(
-        support_dict))
+    support_dict = [
+        "CRAFTFPN",
+        "DBFPN",
+        "EASTFPN",
+        "SASTFPN",
+        "SequenceEncoder",
+    ]
+
+    module_name = config.pop("name")
+    assert module_name in support_dict, Exception(
+        "neck only support {}".format(support_dict)
+    )
     module_class = eval(module_name)(**config)
     return module_class
